.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide_addons.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
imio.annex
==============================================================================


Translations
------------

This product has been translated into

- French


Installation
------------

Install imio.annex by adding it to your buildout::

    [buildout]

    ...

    eggs =
        imio.annex


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/imio.annex/issues
- Source Code: https://github.com/collective/imio.annex


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the GPLv2.
